\name{Samplers for gipps posterior}
\alias{bvsgp}
\alias{gp_pmh}
\alias{gp_mwg}
\alias{gp_gibbs}
\title{Gibbs Posterior For Binary Classification} 
\description{
  This package is built for sampling from the Gibbs posterior. Three samplers are included: pure Metropolis algorithm, Metropolis within gibbs algorithm and gibbs algorithm.
}

\usage{
gp_pmh(Y, X, beta_0=NULL, N=500, burn=1500, 
       lambda=0.05, m_size=4, psi=1, pd=0.5, sigmadd=1, sigmaq=1, const=nrow(X))
gp_mwg(Y, X, Z_0=NULL, Gamma_0=NULL, N=500, burn=1500,
       lambda=0.05, m_size=4, psi=1, pd=0.5, sigma=0.2, const=nrow(X),log=FALSE)
gp_gibbs(Y, X, Z_0=NULL, Gamma_0=NULL, N=500,burn=1500, 
         lambda=0.05, m_size=4, psi=1, sigma=0.2, const=nrow(X), log=FALSE) 
}
\arguments{
  \item{Y}{binary response vector.}
  \item{X}{covariates matrix. The first column corresponds to the pre-selected covariate, and the second column corresponds to intercept term.}
  \item{beta_0}{initial beta vector.}
  \item{Z_0}{initial Z vector.}
  \item{Gamma_0}{initial Gamma vector.}
  \item{N}{number of iterations (after burn in).}
  \item{burn}{number of burn in.}
  \item{lambda}{selection probability.}
  \item{m_size}{model size restriction.}
  \item{psi}{inverse temperature.}
  \item{pd}{probability of add/drop versus swap.}
  \item{sigmadd,sigmaq}{See details in pure Metropolis algorithm.}
  \item{sigma}{See details in Metropolos within gibbs algorithm.}
  \item{const}{constant factor for contructing V matrix.}
  \item{log}{if TRUE, internal computation will be done in log scale.}
}

\details{
Jiang and Tanner (2008) consider a method of classification using the Gibbs posterior which is directedly constructed from the empirical classification errors. This can improve the performance over the usual Bayesian approach, which depends on a probability model which may be misspecified. They propose an algorithm to sample from the Gibbs posterior which utilizes a smoothed approximation of the empirical classification error, via a Gibbs sampler with augmented latent variables. Later, Chen, Jiang and Tanner (2009) note some drawbacks of this algorithm and propose some alternative methods
for sampling from the Gibbs posterior, partially or purly based on the Metropolis algorithm. They find that the Metropolis algorithm produces good classification results at an improved speed of computation.

'gp_gibbs' is based on gibbs algorithm proposed in Section 7 of Jiang and Tanner (2008). 'gp_mvg' is based on Metropolis within gibbs algorithm proposed in Chen (2009). 'gp_pmh' is based on pure Metropolis algorithm proposed in Chen, Jiang and Tanner (2009). Note in 'gp_mwg' and 'gp_gibbs', beta_1 is standardized to be either 1 or -1. Generally, 'gp_pmh' is recommended. 
}

\value{
 These functions all return N steps Markov chain of the beta vector. 
}

\author{Kun Chen, Wenxin Jiang, Martin A. Tanner.}

\references{
Jiang, W. and Tanner, M. A. (2008). Gibbs posterior for variable selection in high dimensional classification and data mining. \emph{Annals of Statistics}. 36, 2207-2231.

Chen, K., Jiang, W. and Tanner, M. A. (2009). A note on some algorithms for the Gibbs posterior. \emph{Techinical Report 09-01}, Department of Statistics, Northwestern University.

Chen, K. (2009). Bayesian variable selection with gibbs posterior for high dimensional classification. \url{http://stat.uiowa.edu/~kuchen/materials/kun_gp.pdf}.
}

\examples{ 
    library(bvsgp)
    ###Simulate data from five dot model.###     
    simd <- fivedot_sim(K=50,n=30,nt=200)
    Y <- simd$Y
    X <- simd$X
    Yt <- simd$Yt
    Xt <- simd$Xt

    ###Use default settings###
    Beta <- gp_pmh(Y,X)

    ###Average training error for 500 steps###
    fit<- X%*%Beta>0
    mean(apply((2*fit-1)*(2*Y-1)==-1,2,sum)/length(Y))

    ###Average test error for last 500 steps###
    pred <- Xt%*%Beta>0
    mean(apply((2*pred-1)*(2*Yt-1)==-1,2,sum)/length(Yt))


    ###Use log=TRUE when sigma is small###
    Beta <- gp_gibbs(Y,X,sigma=0.002,log=TRUE)

}
\keyword{arith}% at least one, from doc/KEYWORDS
